@@ -8,5 +8,4 @@ which gnome-autogen.sh || {
 }
 
 USE_GNOME2_MACROS=1 \
-USE_COMMON_DOC_BUILD=yes \
-gnome-autogen.sh --enable-gtk-doc $@
+gnome-autogen.sh $@
