@@ -50,6 +50,7 @@ static void props_cb (GObject * object, GAsyncResult * res, gpointer user_data);
 #define NOTIFICATION_ITEM_PROP_MENU                  "Menu"
 #define NOTIFICATION_ITEM_PROP_LABEL                 "XAyatanaLabel"
 #define NOTIFICATION_ITEM_PROP_LABEL_GUIDE           "XAyatanaLabelGuide"
+#define NOTIFICATION_ITEM_PROP_TITLE                 "Title"
 #define NOTIFICATION_ITEM_PROP_ORDERING_INDEX        "XAyatanaOrderingIndex"
 
 #define NOTIFICATION_ITEM_SIG_NEW_ICON               "NewIcon"
@@ -57,6 +58,7 @@ static void props_cb (GObject * object, GAsyncResult * res, gpointer user_data);
 #define NOTIFICATION_ITEM_SIG_NEW_STATUS             "NewStatus"
 #define NOTIFICATION_ITEM_SIG_NEW_LABEL              "XAyatanaNewLabel"
 #define NOTIFICATION_ITEM_SIG_NEW_ICON_THEME_PATH    "NewIconThemePath"
+#define NOTIFICATION_ITEM_SIG_NEW_TITLE              "NewTitle"
 
 #define OVERRIDE_GROUP_NAME                          "Ordering Index Overrides"
 #define OVERRIDE_FILE_NAME                           "ordering-override.keyfile"
@@ -67,7 +69,6 @@ struct _ApplicationServiceAppstorePrivate {
 	GDBusConnection * bus;
 	guint dbus_registration;
 	GList * applications;
-	GList * approvers;
 	GHashTable * ordering_overrides;
 };
 
@@ -78,14 +79,6 @@ typedef enum {
 
 #define STATE2STRING(x)  ((x) == VISIBLE_STATE_HIDDEN ? "hidden" : "visible")
 
-typedef struct _Approver Approver;
-struct _Approver {
-	ApplicationServiceAppstore * appstore; /* not ref'd */
-	GCancellable * proxy_cancel;
-	GDBusProxy * proxy;
-	guint name_watcher;
-};
-
 typedef struct _Application Application;
 struct _Application {
 	gchar * id;
@@ -108,10 +101,9 @@ struct _Application {
 	gchar * icon_theme_path;
 	gchar * label;
 	gchar * guide;
+	gchar * title;
 	gboolean currently_free;
 	guint ordering_index;
-	GList * approver_cancels;
-	GList * approved_by;
 	visible_state_t visible_state;
 	guint name_watcher;
 };
@@ -138,16 +130,11 @@ static void load_override_file (GHashTable * hash, const gchar * filename);
 static AppIndicatorStatus string_to_status(const gchar * status_string);
 static void apply_status (Application * app);
 static AppIndicatorCategory string_to_cat(const gchar * cat_string);
-static void approver_free (gpointer papprover, gpointer user_data);
-static void check_with_new_approver (gpointer papp, gpointer papprove);
-static void check_with_old_approver (gpointer papprove, gpointer papp);
 static Application * find_application (ApplicationServiceAppstore * appstore, const gchar * address, const gchar * object);
 static Application * find_application_by_menu (ApplicationServiceAppstore * appstore, const gchar * address, const gchar * menuobject);
 static void bus_get_cb (GObject * object, GAsyncResult * res, gpointer user_data);
 static void dbus_proxy_cb (GObject * object, GAsyncResult * res, gpointer user_data);
 static void app_receive_signal (GDBusProxy * proxy, gchar * sender_name, gchar * signal_name, GVariant * parameters, gpointer user_data);
-static void approver_proxy_cb (GObject * object, GAsyncResult * res, gpointer user_data);
-static void approver_receive_signal (GDBusProxy * proxy, gchar * sender_name, gchar * signal_name, GVariant * parameters, gpointer user_data);
 static void get_all_properties (Application * app);
 static void application_free (Application * app);
 
@@ -192,7 +179,6 @@ application_service_appstore_init (ApplicationServiceAppstore *self)
 	ApplicationServiceAppstorePrivate * priv = APPLICATION_SERVICE_APPSTORE_GET_PRIVATE (self);
 
 	priv->applications = NULL;
-	priv->approvers = NULL;
 	priv->bus_cancel = NULL;
 	priv->dbus_registration = 0;
 
@@ -265,8 +251,8 @@ bus_method_call (GDBusConnection * connection, const gchar * sender,
 	ApplicationServiceAppstore * service = APPLICATION_SERVICE_APPSTORE(user_data);
 	GVariant * retval = NULL;
 	Application *app = NULL;
-	const gchar *dbusaddress;
-	const gchar *dbusmenuobject;
+	gchar *dbusaddress = NULL;
+	gchar *dbusmenuobject = NULL;
 
 	if (g_strcmp0(method, "GetApplications") == 0) {
 		retval = get_applications(service);
@@ -275,20 +261,29 @@ bus_method_call (GDBusConnection * connection, const gchar * sender,
 		gint delta;
 		guint direction;
 
-		g_variant_get (params, "(&s&siu)", &dbusaddress, &dbusmenuobject,
+		g_variant_get (params, "(ssiu)", &dbusaddress, &dbusmenuobject,
 		                                   &delta, &direction);
 
 		switch (direction) {
 			case INDICATOR_OBJECT_SCROLL_UP:
 				delta = -delta;
-			case INDICATOR_OBJECT_SCROLL_DOWN:
 				orientation = "vertical";
 				break;
-
+			case INDICATOR_OBJECT_SCROLL_DOWN:
+				/* delta unchanged */
+				orientation = "vertical";
+				break;
 			case INDICATOR_OBJECT_SCROLL_LEFT:
 				delta = -delta;
-			case INDICATOR_OBJECT_SCROLL_RIGHT:
 				orientation = "horizontal";
+				break;
+			case INDICATOR_OBJECT_SCROLL_RIGHT:
+				/* delta unchanged */
+				orientation = "horizontal";
+				break;
+			default:
+				g_assert_not_reached();
+				break;
 		}
 
 		app = find_application_by_menu(service, dbusaddress, dbusmenuobject);
@@ -301,7 +296,7 @@ bus_method_call (GDBusConnection * connection, const gchar * sender,
 	} else if (g_strcmp0(method, "ApplicationSecondaryActivateEvent") == 0) {
 		guint time;
 
-		g_variant_get (params, "(&s&su)", &dbusaddress, &dbusmenuobject, &time);
+		g_variant_get (params, "(ssu)", &dbusaddress, &dbusmenuobject, &time);
 		app = find_application_by_menu(service, dbusaddress, dbusmenuobject);
 
 		if (app != NULL && app->dbus_proxy != NULL) {
@@ -313,6 +308,9 @@ bus_method_call (GDBusConnection * connection, const gchar * sender,
 		g_warning("Calling method '%s' on the indicator service and it's unknown", method);
 	}
 
+	g_free(dbusaddress);
+	g_free(dbusmenuobject);
+
 	g_dbus_method_invocation_return_value(invocation, retval);
 	return;
 }
@@ -328,12 +326,6 @@ application_service_appstore_dispose (GObject *object)
 		                                           ((Application *)priv->applications->data)->dbus_object);
 	}
 
-	if (priv->approvers != NULL) {
-		g_list_foreach(priv->approvers, approver_free, object);
-		g_list_free(priv->approvers);
-		priv->approvers = NULL;
-	}
-
 	if (priv->dbus_registration != 0) {
 		g_dbus_connection_unregister_object(priv->bus, priv->dbus_registration);
 		/* Don't care if it fails, there's nothing we can do */
@@ -403,7 +395,7 @@ load_override_file (GHashTable * hash, const gchar * filename)
 		return;
 	}
 
-	gchar * key = keys[0];
+	gchar * key;
 	gint i;
 
 	for (i = 0; (key = keys[i]) != NULL; i++) {
@@ -440,7 +432,7 @@ got_all_properties (GObject * source_object, GAsyncResult * res,
 	         * status = NULL, * icon_name = NULL, * aicon_name = NULL,
 	         * icon_desc = NULL, * aicon_desc = NULL,
 	         * icon_theme_path = NULL, * index = NULL, * label = NULL,
-	         * guide = NULL;
+	         * guide = NULL, * title = NULL;
 
 	GVariant * properties = g_dbus_proxy_call_finish(G_DBUS_PROXY(source_object), res, &error);
 
@@ -494,6 +486,8 @@ got_all_properties (GObject * source_object, GAsyncResult * res,
 			label = g_variant_ref(value);
 		} else if (g_strcmp0(name, NOTIFICATION_ITEM_PROP_LABEL_GUIDE) == 0) {
 			guide = g_variant_ref(value);
+		} else if (g_strcmp0(name, NOTIFICATION_ITEM_PROP_TITLE) == 0) {
+			title = g_variant_ref(value);
 		} /* else ignore */
 	}
 	g_variant_iter_free (iter);
@@ -581,7 +575,12 @@ got_all_properties (GObject * source_object, GAsyncResult * res,
 			app->guide = g_strdup("");
 		}
 
-		g_list_foreach(priv->approvers, check_with_old_approver, app);
+		g_free(app->title);
+		if (title != NULL) {
+			app->title = g_variant_dup_string(title, NULL);
+		} else {
+			app->title = g_strdup("");
+		}
 
 		apply_status(app);
 
@@ -603,6 +602,7 @@ got_all_properties (GObject * source_object, GAsyncResult * res,
 	if (index)           g_variant_unref (index);
 	if (label)           g_variant_unref (label);
 	if (guide)           g_variant_unref (guide);
+	if (title)           g_variant_unref (title);
 
 	return;
 }
@@ -623,15 +623,6 @@ get_all_properties (Application * app)
 	}
 }
 
-/* Check the application against an approver */
-static void
-check_with_old_approver (gpointer papprove, gpointer papp)
-{
-	/* Funny the parallels, eh? */
-	check_with_new_approver(papp, papprove);
-	return;
-}
-
 /* Simple translation function -- could be optimized */
 static AppIndicatorStatus
 string_to_status(const gchar * status_string)
@@ -784,13 +775,8 @@ application_free (Application * app)
 	if (app->guide != NULL) {
 		g_free(app->guide);
 	}
-	if (app->approver_cancels != NULL) {
-		g_list_foreach(app->approver_cancels, (GFunc)g_cancellable_cancel, NULL);
-		g_list_foreach(app->approver_cancels, (GFunc)g_object_unref, NULL);
-		g_list_free(app->approver_cancels);
-	}
-	if (app->approved_by != NULL) {
-		g_list_free(app->approved_by);
+	if (app->title != NULL) {
+		g_free(app->title);
 	}
 
 	g_free(app);
@@ -855,14 +841,12 @@ static void
 apply_status (Application * app)
 {
 	ApplicationServiceAppstore * appstore = app->appstore;
-	ApplicationServiceAppstorePrivate * priv = appstore->priv;
 
-	/* g_debug("Applying status.  Status: %d  Approved by: %d  Approvers: %d  Visible: %d", app->status, g_list_length(app->approved_by), g_list_length(priv->approvers), app->visible_state); */
+	/* g_debug("Applying status.  Status: %d  Visible: %d", app->status, app->visible_state); */
 
 	visible_state_t goal_state = VISIBLE_STATE_HIDDEN;
 
-	if (app->status != APP_INDICATOR_STATUS_PASSIVE && 
-			g_list_length(app->approved_by) >= g_list_length(priv->approvers)) {
+	if (app->status != APP_INDICATOR_STATUS_PASSIVE) {
 		goal_state = VISIBLE_STATE_SHOWN;
 	}
 
@@ -906,12 +890,12 @@ apply_status (Application * app)
 		if (app->visible_state == VISIBLE_STATE_HIDDEN) {
 			/* Put on panel */
 			emit_signal (appstore, "ApplicationAdded",
-				     g_variant_new ("(sisosssss)", newicon,
+				     g_variant_new ("(sisossssss)", newicon,
 			                            get_position(app),
 			                            app->dbus_name, app->menu,
 			                            app->icon_theme_path,
 			                            app->label, app->guide,
-			                            newdesc, app->id));
+			                            newdesc, app->id, app->title));
 		} else {
 			/* Icon update */
 			gint position = get_position(app);
@@ -923,6 +907,9 @@ apply_status (Application * app)
 				     g_variant_new ("(iss)", position, 
 		                                    app->label != NULL ? app->label : "",
 		                                    app->guide != NULL ? app->guide : ""));
+			emit_signal (appstore, "ApplicationTitleChanged",
+				     g_variant_new ("(is)", position,
+		                                    app->title != NULL ? app->title : ""));
 		}
 	}
 
@@ -1019,7 +1006,7 @@ application_service_appstore_application_add (ApplicationServiceAppstore * appst
 	Application * app = find_application(appstore, dbus_name, dbus_object);
 
 	if (app != NULL) {
-		g_warning("Application already exists, re-requesting properties.");
+		g_debug("Application already exists, re-requesting properties.");
 		get_all_properties(app);
 		return;
 	}
@@ -1039,10 +1026,9 @@ application_service_appstore_application_add (ApplicationServiceAppstore * appst
 	app->icon_theme_path = NULL;
 	app->label = NULL;
 	app->guide = NULL;
+	app->title = NULL;
 	app->currently_free = FALSE;
 	app->ordering_index = 0;
-	app->approver_cancels = NULL;
-	app->approved_by = NULL;
 	app->visible_state = VISIBLE_STATE_HIDDEN;
 	app->name_watcher = 0;
 	app->props_cancel = NULL;
@@ -1076,11 +1062,13 @@ name_changed (GDBusConnection * connection, const gchar * sender_name,
 {
 	Application * app = (Application *)user_data;
 
-	const gchar * new_name;
-	g_variant_get(parameters, "(&s&s&s)", NULL, NULL, &new_name);
+	gchar * new_name = NULL;
+	g_variant_get(parameters, "(sss)", NULL, NULL, &new_name);
 
 	if (new_name == NULL || new_name[0] == 0)
 		application_died(app);
+
+	g_free(new_name);
 }
 
 /* Callback from trying to create the proxy for the app. */
@@ -1198,20 +1186,28 @@ app_receive_signal (GDBusProxy * proxy, gchar * sender_name, gchar * signal_name
 		/* aicon name isn't provided by signal, so look it up */
 		get_all_properties(app);
 	}
+	else if (g_strcmp0(signal_name, NOTIFICATION_ITEM_SIG_NEW_TITLE) == 0) {
+		/* title name isn't provided by signal, so look it up */
+		get_all_properties(app);
+	}
 	else if (g_strcmp0(signal_name, NOTIFICATION_ITEM_SIG_NEW_STATUS) == 0) {
-		const gchar * status;
-		g_variant_get(parameters, "(&s)", &status);
+		gchar * status = NULL;
+		g_variant_get(parameters, "(s)", &status);
 		new_status(app, status);
+		g_free(status);
 	}
 	else if (g_strcmp0(signal_name, NOTIFICATION_ITEM_SIG_NEW_ICON_THEME_PATH) == 0) {
-		const gchar * icon_theme_path;
-		g_variant_get(parameters, "(&s)", &icon_theme_path);
+		gchar * icon_theme_path = NULL;
+		g_variant_get(parameters, "(s)", &icon_theme_path);
 		new_icon_theme_path(app, icon_theme_path);
+		g_free(icon_theme_path);
 	}
 	else if (g_strcmp0(signal_name, NOTIFICATION_ITEM_SIG_NEW_LABEL) == 0) {
-		const gchar * label, * guide;
-		g_variant_get(parameters, "(&s&s)", &label, &guide);
+		gchar * label = NULL, * guide = NULL;
+		g_variant_get(parameters, "(ss)", &label, &guide);
 		new_label(app, label, guide);
+		g_free(label);
+		g_free(guide);
 	}
 
 	return;
@@ -1315,7 +1311,7 @@ get_applications (ApplicationServiceAppstore * appstore)
 		GList * listpntr;
 		gint position = 0;
 
-		g_variant_builder_init(&builder, G_VARIANT_TYPE_ARRAY);
+		g_variant_builder_init(&builder, G_VARIANT_TYPE ("a(sisossssss)"));
 
 		for (listpntr = priv->applications; listpntr != NULL; listpntr = g_list_next(listpntr)) {
 			Application * app = (Application *)listpntr->data;
@@ -1323,20 +1319,20 @@ get_applications (ApplicationServiceAppstore * appstore)
 				continue;
 			}
 
-			g_variant_builder_add (&builder, "(sisosssss)", app->icon,
+			g_variant_builder_add (&builder, "(sisossssss)", app->icon,
 			                       position++, app->dbus_name, app->menu,
 			                       app->icon_theme_path, app->label,
 			                       app->guide,
 			                       (app->icon_desc != NULL) ? app->icon_desc : "",
-			                       app->id);
+			                       app->id, app->title);
 		}
 
 		out = g_variant_builder_end(&builder);
 	} else {
 		GError * error = NULL;
-		out = g_variant_parse(g_variant_type_new("a(sisosssss)"), "[]", NULL, NULL, &error);
+		out = g_variant_parse(g_variant_type_new("a(sisossssss)"), "[]", NULL, NULL, &error);
 		if (error != NULL) {
-			g_warning("Unable to parse '[]' as a 'a(sisosssss)': %s", error->message);
+			g_warning("Unable to parse '[]' as a 'a(sisossssss)': %s", error->message);
 			out = NULL;
 			g_error_free(error);
 		}
@@ -1348,272 +1344,3 @@ get_applications (ApplicationServiceAppstore * appstore)
 		return NULL;
 	}
 }
-
-/* Removes and approver from our list of approvers and
-   then sees if that changes our status.  Most likely this
-   could make us visible if this approver rejected us. */
-static void
-remove_approver (gpointer papp, gpointer pproxy)
-{
-	Application * app = (Application *)papp;
-
-	/* Check for any pending approvals and cancel them */
-	GList * iter = app->approver_cancels;
-	while (iter != NULL) {
-		GCancellable * cancel = (GCancellable *)iter->data;
-		GDBusProxy * proxy = (GDBusProxy *)g_object_get_data(G_OBJECT(cancel), "proxy");
-		if (proxy == pproxy) {
-			g_cancellable_cancel(cancel);
-			g_object_unref(cancel);
-
-			GList * next = iter->next;
-			app->approver_cancels = g_list_delete_link(app->approver_cancels, iter);
-			iter = next;
-		} else {
-			iter = iter->next;
-		}
-	}
-
-	app->approved_by = g_list_remove(app->approved_by, pproxy);
-	apply_status(app);
-	return;
-}
-
-/* Frees the data associated with an approver */
-static void
-approver_free (gpointer papprover, gpointer user_data)
-{
-	Approver * approver = (Approver *)papprover;
-	g_return_if_fail(approver != NULL);
-
-	ApplicationServiceAppstore * appstore = APPLICATION_SERVICE_APPSTORE(user_data);
-	g_list_foreach(appstore->priv->applications, remove_approver, approver->proxy);
-	
-	if (approver->name_watcher != 0) {
-		g_dbus_connection_signal_unsubscribe(g_dbus_proxy_get_connection(approver->proxy), approver->name_watcher);
-		approver->name_watcher = 0;
-	}
-
-	if (approver->proxy != NULL) {
-		g_object_unref(approver->proxy);
-		approver->proxy = NULL;
-	}
-
-	if (approver->proxy_cancel != NULL) {
-		g_cancellable_cancel(approver->proxy_cancel);
-		g_object_unref(approver->proxy_cancel);
-		approver->proxy_cancel = NULL;
-	}
-
-	g_free(approver);
-	return;
-}
-
-/* What did the approver tell us? */
-static void
-approver_request_cb (GObject *object, GAsyncResult *res, gpointer user_data)
-{
-	GDBusProxy * proxy = G_DBUS_PROXY(object);
-	GCancellable * cancel = (GCancellable *)user_data;
-	GError * error = NULL;
-	gboolean approved = TRUE; /* default to approved */
-	GVariant * result;
-
-	result = g_dbus_proxy_call_finish(proxy, res, &error);
-
-	if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
-		g_error_free (error);
-		return; // Must exit before accessing freed memory
-	}
-
-	Application * app = (Application *)g_object_get_data(G_OBJECT(cancel), "app");
-	app->approver_cancels = g_list_remove(app->approver_cancels, cancel);
-	g_object_unref(cancel);
-
-	if (error == NULL) {
-		g_variant_get(result, "(b)", &approved);
-		g_debug("Approver responded: %s", approved ? "approve" : "rejected");
-	}
-	else {
-		g_debug("Approver responded error: %s", error->message);
-		g_error_free (error);
-	}
-
-	if (approved) {
-		app->approved_by = g_list_prepend(app->approved_by, proxy);
-	} else {
-		app->approved_by = g_list_remove(app->approved_by, proxy);
-	}
-
-	apply_status(app);
-	return;
-}
-
-/* Run the applications through the new approver */
-static void
-check_with_new_approver (gpointer papp, gpointer papprove)
-{
-	Application * app = (Application *)papp;
-	Approver * approver = (Approver *)papprove;
-	GCancellable * cancel = NULL;
-
-	cancel = g_cancellable_new();
-	g_object_set_data(G_OBJECT(cancel), "app", app);
-	g_object_set_data(G_OBJECT(cancel), "proxy", approver->proxy);
-	app->approver_cancels = g_list_prepend(app->approver_cancels, cancel);
-
-	g_dbus_proxy_call(approver->proxy, "ApproveItem",
-	                  g_variant_new("(ssuso)", app->id, app->category,
-	                                0, app->dbus_name, app->dbus_object),
-	                  G_DBUS_CALL_FLAGS_NONE, -1, cancel,
-	                  approver_request_cb, cancel);
-
-	return;
-}
-
-/* A signal when an approver changes the why that it thinks about
-   a particular indicator. */
-void
-approver_revise_judgement (Approver * approver, gboolean new_status, const gchar * address, const gchar * path)
-{
-	g_return_if_fail(address != NULL && address[0] != '\0');
-	g_return_if_fail(path != NULL && path[0] != '\0');
-
-	Application * app = find_application(approver->appstore, address, path);
-
-	if (app == NULL) {
-		g_warning("Unable to update approver status of application (%s:%s) as it was not found", address, path);
-		return;
-	}
-
-	if (new_status) {
-		app->approved_by = g_list_prepend(app->approved_by, approver->proxy);
-	} else {
-		app->approved_by = g_list_remove(app->approved_by, approver->proxy);
-	}
-	apply_status(app);
-
-	return;
-}
-
-/* Adds a new approver to the app store */
-void
-application_service_appstore_approver_add (ApplicationServiceAppstore * appstore, const gchar * dbus_name, const gchar * dbus_object)
-{
-	g_return_if_fail(IS_APPLICATION_SERVICE_APPSTORE(appstore));
-	g_return_if_fail(dbus_name != NULL);
-	g_return_if_fail(dbus_object != NULL);
-	ApplicationServiceAppstorePrivate * priv = APPLICATION_SERVICE_APPSTORE_GET_PRIVATE (appstore);
-
-	Approver * approver = g_new0(Approver, 1);
-	approver->appstore = appstore;
-	approver->proxy_cancel = NULL;
-	approver->proxy = NULL;
-	approver->name_watcher = 0;
-
-	approver->proxy_cancel = g_cancellable_new();
-	g_dbus_proxy_new_for_bus(G_BUS_TYPE_SESSION,
-			         G_DBUS_PROXY_FLAGS_NONE,
-			         NULL,
-	                         dbus_name,
-	                         dbus_object,
-	                         NOTIFICATION_APPROVER_DBUS_IFACE,
-			         approver->proxy_cancel,
-			         approver_proxy_cb,
-		                 approver);
-
-	priv->approvers = g_list_prepend(priv->approvers, approver);
-
-	return;
-}
-
-static void
-approver_name_changed (GDBusConnection * connection, const gchar * sender_name,
-                       const gchar * object_path, const gchar * interface_name,
-                       const gchar * signal_name, GVariant * parameters,
-                       gpointer user_data)
-{
-	Approver * approver = (Approver *)user_data;
-	ApplicationServiceAppstore * appstore = approver->appstore;
-
-	const gchar * new_name;
-	g_variant_get(parameters, "(&s&s&s)", NULL, NULL, &new_name);
-
-	if (new_name == NULL || new_name[0] == 0) {
-		appstore->priv->approvers = g_list_remove(appstore->priv->approvers, approver);
-		approver_free(approver, appstore);
-	}
-}
-
-/* Callback from trying to create the proxy for the approver. */
-static void
-approver_proxy_cb (GObject * object, GAsyncResult * res, gpointer user_data)
-{
-	GError * error = NULL;
-
-	Approver * approver = (Approver *)user_data;
-	g_return_if_fail(approver != NULL);
-
-	GDBusProxy * proxy = g_dbus_proxy_new_for_bus_finish(res, &error);
-
-	if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
-		g_error_free (error);
-		return; // Must exit before accessing freed memory
-	}
-
-	ApplicationServiceAppstorePrivate * priv = APPLICATION_SERVICE_APPSTORE_GET_PRIVATE (approver->appstore);
-
-	if (approver->proxy_cancel != NULL) {
-		g_object_unref(approver->proxy_cancel);
-		approver->proxy_cancel = NULL;
-	}
-
-	if (error != NULL) {
-		g_critical("Could not grab DBus proxy for approver: %s", error->message);
-		g_error_free(error);
-		return;
-	}
-
-	/* Okay, we're good to grab the proxy at this point, we're
-	sure that it's ours. */
-	approver->proxy = proxy;
-
-	/* We've got it, let's watch it for destruction */
-	approver->name_watcher = g_dbus_connection_signal_subscribe(
-	                                   g_dbus_proxy_get_connection(proxy),
-	                                   "org.freedesktop.DBus",
-	                                   "org.freedesktop.DBus",
-	                                   "NameOwnerChanged",
-	                                   "/org/freedesktop/DBus",
-	                                   g_dbus_proxy_get_name(proxy),
-	                                   G_DBUS_SIGNAL_FLAGS_NONE,
-	                                   approver_name_changed,
-	                                   approver,
-	                                   NULL);
-
-	g_signal_connect(proxy, "g-signal", G_CALLBACK(approver_receive_signal),
-	                 approver);
-
-	g_list_foreach(priv->applications, check_with_new_approver, approver);
-
-	return;
-}
-
-/* Receives all signals from the service, routed to the appropriate functions */
-static void
-approver_receive_signal (GDBusProxy * proxy, gchar * sender_name, gchar * signal_name,
-                         GVariant * parameters, gpointer user_data)
-{
-	Approver * approver = (Approver *)user_data;
-
-	if (g_strcmp0(signal_name, "ReviseJudgement") == 0) {
-		gboolean approved;
-		const gchar * address;
-		const gchar * path;
-		g_variant_get(parameters, "(b&s&o)", &approved, &address, &path);
-		approver_revise_judgement(approver, approved, address, path);
-	}
-
-	return;
-}
-
